@@ -1,5 +1,4 @@
 from ..core import StructuredNode
-from ..util import items
 
 
 class Hierarchical(object):
@@ -45,7 +44,7 @@ class Hierarchical(object):
         except TypeError:
             super(Hierarchical, self).__init__()
         self.__parent__ = None
-        for key, value in items(kwargs):
+        for key, value in kwargs.items():
             if key == "__parent__":
                 self.__parent__ = value
 
